changeset 31873:7c690775716c v9.0.1269

patch 9.0.1269: channel test often fails on Mac OS Commit: https://github.com/vim/vim/commit/b40c1de38442a26f31efb8473adec7fad560f3d0 Author: Bram Moolenaar <Bram@vim.org> Date: Tue Jan 31 21:01:08 2023 +0000 patch 9.0.1269: channel test often fails on Mac OS Problem: Channel test often fails on Mac OS. Solution: Increase the wait time from one to 15 milliseconds. (D. Ben Knoble, closes #11894)
author Bram Moolenaar <Bram@vim.org>
date Tue, 31 Jan 2023 22:15:03 +0100
parents 4df399e99057
children 7325519b56fc
files src/channel.c src/version.c
diffstat 2 files changed, 8 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -696,6 +696,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1269,
+/**/
     1268,
 /**/
     1267,
--- a/src/channel.c
+++ b/src/channel.c
@@ -979,11 +979,13 @@ channel_open(
 
 	ch_log(channel, "Trying to connect to %s port %d", dst, port);
 
 	// On Mac and Solaris a zero timeout almost never works.  At least wait
 	// one millisecond.  Let's do it for all systems, because we don't know
 	// why this is needed.
 	if (waittime == 0)
-	    waittime = 1;
+	    waittime = 15;
 
 	sd = channel_connect(channel, addr->ai_addr, (int)addr->ai_addrlen,
 								   &waittime);
@@ -979,11 +979,13 @@ channel_open(
 	ch_log(channel, "Trying to connect to %s port %d", dst, port);
 
-	// On Mac and Solaris a zero timeout almost never works.  At least wait
-	// one millisecond.  Let's do it for all systems, because we don't know
-	// why this is needed.
+	// On Mac and Solaris a zero timeout almost never works.  Waiting for
+	// one millisecond already helps a lot.  Later Mac systems (using IPv6)
+	// need more time, 15 milliseconds appears to work well.
+	// Let's do it for all systems, because we don't know why this is
+	// needed.
 	if (waittime == 0)